<?php
/**
 * Post carousel widgets
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class TJ_Extras_Widget_Post_Slider extends Widget_Base {

	public function get_name() {
		return 'tj-extras-post-slider';
	}

	public function get_title() {
		return esc_html__( 'Post Slider', 'tj-extras' );
	}

	public function get_icon() {
		return 'eicon-slider-3d';
	}

	public function get_keywords() {
		return [ 'blog', 'post', 'slider' ];
	}

	public function get_categories() {
		return [ 'tj_extras_elements' ];
	}

	public function get_script_depends() {
		return [ 'owl-carousel', 'post-slider' ];
	}

	public function get_style_depends() {
		return [ 'owl-carousel', 'owl-carousel-theme' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'post_slider',
			[
				'label' => esc_html__( 'Post Slider', 'tj-extras' ),
			]
		);

		$this->add_control(
			'count',
			[
				'label'         => esc_html__( 'Posts Per Page', 'tj-extras' ),
				'description'   => esc_html__( 'You can enter "-1" to display all items.', 'tj-extras' ),
				'type'          => Controls_Manager::TEXT,
				'default'       => '6',
				'label_block'   => true,
			]
		);

		$this->add_control(
			'order',
			[
				'label'         => esc_html__( 'Order', 'tj-extras' ),
				'type'          => Controls_Manager::SELECT,
				'default'       => '',
				'options'       => [
					''          => esc_html__( 'Default', 'tj-extras' ),
					'DESC'      => esc_html__( 'DESC', 'tj-extras' ),
					'ASC'       => esc_html__( 'ASC', 'tj-extras' ),
				],
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'         => esc_html__( 'Order By', 'tj-extras' ),
				'type'          => Controls_Manager::SELECT,
				'default'       => '',
				'options'       => [
					''              => esc_html__( 'Default', 'tj-extras' ),
					'date'          => esc_html__( 'Date', 'tj-extras' ),
					'title'         => esc_html__( 'Title', 'tj-extras' ),
					'name'          => esc_html__( 'Name', 'tj-extras' ),
					'modified'      => esc_html__( 'Modified', 'tj-extras' ),
					'author'        => esc_html__( 'Author', 'tj-extras' ),
					'rand'          => esc_html__( 'Random', 'tj-extras' ),
					'ID'            => esc_html__( 'ID', 'tj-extras' ),
					'comment_count' => esc_html__( 'Comment Count', 'tj-extras' ),
					'menu_order'    => esc_html__( 'Menu Order', 'tj-extras' ),
				],
			]
		);

		$this->add_control(
			'include_categories',
			[
				'label' 		=> esc_html__( 'Include Categories', 'tj-extras' ),
				'description' 	=> esc_html__( 'Enter the categories slugs seperated by a "comma"', 'tj-extras' ),
				'type' 			=> Controls_Manager::TEXT,
				'label_block' 	=> true,
			]
		);

		$this->add_control(
			'exclude_categories',
			[
				'label' 		=> esc_html__( 'Exclude Categories', 'tj-extras' ),
				'description' 	=> esc_html__( 'Enter the categories slugs seperated by a "comma"', 'tj-extras' ),
				'type' 			=> Controls_Manager::TEXT,
				'label_block' 	=> true,
			]
		);

		$this->add_control(
			'include_tags',
			[
				'label'         => esc_html__( 'Include Tags', 'tj-extras' ),
				'description'   => esc_html__( 'Enter the tags slugs seperated by a "comma"', 'tj-extras' ),
				'type'          => Controls_Manager::TEXT,
				'label_block'   => true,
			]
		);

		$this->add_control(
			'image_size',
			[
				'label' 		=> esc_html__( 'Image Size', 'tj-extras' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> 'large',
				'options' 		=> $this->get_img_sizes(),
			]
		);

		$this->end_controls_section();

	}

	public function get_img_sizes() {
		global $_wp_additional_image_sizes;

		$sizes = array();
		$get_intermediate_image_sizes = get_intermediate_image_sizes();

		// Create the full array with sizes and crop info
		foreach( $get_intermediate_image_sizes as $_size ) {
			if ( in_array( $_size, array( 'thumbnail', 'medium', 'medium_large', 'large' ) ) ) {
				$sizes[ $_size ]['width'] 	= get_option( $_size . '_size_w' );
				$sizes[ $_size ]['height'] 	= get_option( $_size . '_size_h' );
				$sizes[ $_size ]['crop'] 	= (bool) get_option( $_size . '_crop' );
			} elseif ( isset( $_wp_additional_image_sizes[ $_size ] ) ) {
				$sizes[ $_size ] = array(
					'width' 	=> $_wp_additional_image_sizes[ $_size ]['width'],
					'height' 	=> $_wp_additional_image_sizes[ $_size ]['height'],
					'crop' 		=> $_wp_additional_image_sizes[ $_size ]['crop'],
				);
			}
		}

		$image_sizes = array();

		foreach ( $sizes as $size_key => $size_attributes ) {
			$image_sizes[ $size_key ] = ucwords( str_replace( '_', ' ', $size_key ) ) . sprintf( ' - %d x %d', $size_attributes['width'], $size_attributes['height'] );
		}

		$image_sizes['full'] 	= _x( 'Full', 'Image Size Control', 'tj-extras' );

		return $image_sizes;
	}

	protected function render() {
		$settings = $this->get_settings();

		// Vars
		$posts_per_page = $settings['count'];
		$order 			= $settings['order'];
		$orderby  		= $settings['orderby'];
		$include 		= $settings['include_categories'];
		$exclude 		= $settings['exclude_categories'];

		$args = array(
			'posts_per_page' => $posts_per_page,
			'post_type'      => 'post',
			'order'          => $order,
			'orderby'        => $orderby
		);

		// Include category
		if ( ! empty( $include ) ) {

			// Sanitize category and convert to array
			$include = str_replace( ', ', ',', $include );
			$include = explode( ',', $include );

			// Add to query arg
			$args['tax_query'][] = array(
				'taxonomy' => 'category',
				'field'    => 'slug',
				'terms'    => $include,
				'operator' => 'IN',
			);

		}

		// Exclude category
		if ( ! empty( $exclude ) ) {

			// Sanitize category and convert to array
			$exclude = str_replace( ', ', ',', $exclude );
			$exclude = explode( ',', $exclude );

			// Add to query arg
			$args['tax_query'][] = array(
				'taxonomy' => 'category',
				'field'    => 'slug',
				'terms'    => $exclude,
				'operator' => 'NOT IN',
			);

		}

		// Include tag
		if ( ! empty( $tags ) ) {

			// Sanitize category and convert to array
			$tags = str_replace( ', ', ',', $tags );
			$tags = explode( ',', $tags );

			// Add to query arg
			$args['tax_query'][] = array(
				'taxonomy' => 'post_tag',
				'field'    => 'slug',
				'terms'    => $tags,
				'operator' => 'IN',
			);

		}

		// Build the WordPress query
		$blog = new \WP_Query( $args );

		// Output posts
		if ( $blog->have_posts() ) :

			// Image size
			$img_size = $settings['image_size'];
			$img_size = $img_size ? $img_size : 'large';

			// Wrapper classes
			$wrap_classes = array( 'posts', 'owl-carousel', 'owl-theme', 'post-slider' );
			$wrap_classes = implode( ' ', $wrap_classes );
			?>

			<div class="<?php echo esc_attr( $wrap_classes ); ?>">

				<?php

				// Start loop
				while ( $blog->have_posts() ) : $blog->the_post(); ?>

					<article class="entry">

						<a class="post-thumbnail" href="<?php the_permalink(); ?>">
							<?php
								the_post_thumbnail( $img_size, array(
									'alt' => the_title_attribute( array(
										'echo' => false,
									) ),
								) );
							?>
							<span class="post-thumbnail-overlay"></span>
						</a>

						<header class="entry-header">

							<?php
								$category = get_the_category( get_the_ID() );
								if ( $category ) :
							?>
								<span class="cat-links">
									<a href="<?php echo esc_url( get_category_link( $category[0]->term_id ) ); ?>"><?php echo esc_attr( $category[0]->name ); ?></a>
								</span>
							<?php endif; // End if categories ?>

							<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>

							<div class="entry-meta">
								<?php
									$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
									$time_string = sprintf( $time_string,
										esc_attr( get_the_date( 'c' ) ),
										human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) )
									);
									$posted_on = sprintf(
										/* translators: %s: ago. */
										esc_html_x( '%s ago', 'post date', 'masterwp' ),
										'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
									);
									$byline = sprintf(
										esc_html__( 'by %s', 'masterwp' ),
										'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
									);
									echo '<span class="byline"> ' . $byline . '</span><span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.
								?>
							</div>

						</header>

					</article>

				<?php
				// End entry loop
				endwhile; ?>

			</div><!-- .posts -->

			<?php
			// Reset the post data to prevent conflicts with WP globals
			wp_reset_postdata();

		else : ?>

			<?php get_template_part( 'partials/content/content', 'none' ); ?>

		<?php endif; ?>

	<?php
	}

}

Plugin::instance()->widgets_manager->register_widget_type( new TJ_Extras_Widget_Post_Slider() );
